@@ -26,17 +26,19 @@ char getio(char ownname[])
 void do_switch()
 {
 	for(;;) {
-		switch(inb(PORT)) {
-			case ON:
-				system(SCRIPT1);
-				while(inb(PORT)==ON) {
-					usleep(50000);
-				}
-			case OFF:
-				system(SCRIPT2);
-				while(inb(PORT)==OFF) {
-					usleep(50000);
-				}
+		if (inb(PORT) == ON) {
+			system(SCRIPT1);
+			while(inb(PORT)==ON) {
+				usleep(500000);
+			}
+		}
+		else {
+			if (inb(PORT) == OFF) {
+						system(SCRIPT2);
+						while(inb(PORT)==OFF) {
+							usleep(500000);
+						}
+			}
 		}
 	usleep(100000);
 	}
